@@ -226,7 +226,7 @@ if [[ $CLOUDPLATFORM == "AZURE" ]];then
   AZUREFILE_SHARES="cms-content cms-metadata-manager-content cms-conf cms-plugin backup-restore cmscli-plugin cms-sync-utils cms-service-client cms-workflow-runtime"
 
   # Database disk size, common for both aks and gke
-  PG_DISK_SIZE=$(get_parameter_value pg_disk_size)
+  PG_DISK_SIZE=$(get_parameter_value pg_disk_size "30")
 
   #Pod CIDR
   POD_CIDR=$(get_parameter_value kubernetes_pod_cidr)
