@@ -122,6 +122,17 @@ def k8s_scale_0(kind, namespace, name):
   print('')
   return _continue
 
+def k8s_scale_1(kind, namespace, name):
+  result, err = exec_cmd("kubectl get " + kind + " -n " + namespace +" "+ name +" -o yaml|yq .spec.replicas")
+  if err:
+    logger.error("Fail to get replicas of " + kind + " [" + name + "]")
+    exit(1)
+  if result[0] == '0':
+    logger.info("Temporally scale " + name + " with replicas 1 to ensure service dependency is satisfied.") 
+    result, err = exec_cmd("kubectl scale " + kind + " --replicas=1 -n " + namespace +" "+ name)
+    if err:
+      logger.error("Fail to set replicas of " + kind + " [" + name + "] to 1!")
+      exit(1)
 
 def yamltodic(root, filepath):
   _dict = {}
@@ -242,7 +253,7 @@ def system_check():
     logger.error("Helm is not installed in this node, make sure to run this scripts in the bootstrap node.")
     exit(1)
 
-  out, err = exec_cmd("kubectl version")
+  out, err = exec_cmd("kubectl version --output=yaml")
   logger.debug(out)
 
   if err:
@@ -1066,6 +1077,12 @@ def rollback_charts(deploy_list, namespace, interval, snapshot_name):
               process_dict[release] = cmd_proc
         else:
           logger.info("Bypass rollback for [" + release + "] as current revision is same as target revision")
+          if release == "cms-oauth":
+             k8s_scale_1("deploy", namespace, "cms-oauth")
+          if release == "cms-metadata-manager":
+             k8s_scale_1("deploy", namespace, "cms-metadata-manager")
+          if release == "cms-workflow":
+             k8s_scale_1("deploy", namespace, "cms-workflow")
         
     # Wait for all command to be executed and get the results
     for release,p in process_dict.items():
