@@ -170,6 +170,18 @@ else
   info_log "No EPG database deployed, will skip EPG database migration. "
 fi
 
+PG_SETUP_CHART_VERSION=""
+function get_pg_setup_chart_version(){
+  PG_SETUP_TGZ_FILE=$(ls ${HELM_REPO_PATH}|grep -E 'cms-pg-setup.*tgz')
+  PG_SETUP_CHART_VERSION=$(helm inspect chart ${HELM_REPO_PATH}/${PG_SETUP_TGZ_FILE} | grep '^version:' | awk '{print $2}')
+  if [ $? -ne 0 ]; then
+    error_log "Fail to get cms-pg-setup chart version from ${HELM_REPO_PATH}/${PG_SETUP_TGZ_FILE}"
+    exit 1
+  fi
+}
+
+get_pg_setup_chart_version
+info_log "cms-pg-setup chart version:${PG_SETUP_CHART_VERSION}"
 
 if [ -z "$AZURE_DB_NAME" ]; then
   echo 
@@ -190,7 +202,7 @@ else
   
   info_log "Deploy the Helm Chart to upgrade postgreSQL and migrate database data."
   TGZ_FILE=$(ls ${HELM_REPO_PATH}|grep -E 'cms-container-pg-upgrade.*tgz')
-  helm install cms-container-pg-upgrade --set image.repository=${IMAGE_REGISTRY},db_host=$HOST,db_name=$AZURE_DB_NAME,azuredb=true,epgEnable=$EPG_ENABLE,force_upgrade=$FORCE_UPGRADE,pg_password=$SUPER_USER_PASSWORD -n ${CMS_NAMESPACE} ${HELM_REPO_PATH}/${TGZ_FILE}
+  helm install cms-container-pg-upgrade --set image.repository=${IMAGE_REGISTRY},db_host=$HOST,db_name=$AZURE_DB_NAME,azuredb=true,epgEnable=$EPG_ENABLE,force_upgrade=$FORCE_UPGRADE,pg_password=$SUPER_USER_PASSWORD,pg_setup_chart_version=${PG_SETUP_CHART_VERSION} -n ${CMS_NAMESPACE} ${HELM_REPO_PATH}/${TGZ_FILE}
 
   if [ $? -ne 0 ]; then 
     error_log "Deploy the Helm Chart files fail. Please fix the error and execute this script again."
@@ -334,7 +346,7 @@ uninstall_container_before_upgrade
 
 info_log "Deploy the Helm Chart to upgrade postgreSQL and migrate database data."
 TGZ_FILE=$(ls ${HELM_REPO_PATH}|grep -E 'cms-container-pg-upgrade.*tgz')
-helm install cms-container-pg-upgrade --set image.repository=${IMAGE_REGISTRY},epgEnable=$EPG_ENABLE -n ${CMS_NAMESPACE} ${HELM_REPO_PATH}/${TGZ_FILE}
+helm install cms-container-pg-upgrade --set image.repository=${IMAGE_REGISTRY},epgEnable=$EPG_ENABLE,pg_setup_chart_version=${PG_SETUP_CHART_VERSION} -n ${CMS_NAMESPACE} ${HELM_REPO_PATH}/${TGZ_FILE}
 if [ $? -ne 0 ]; then 
     error_log "Deploy the Helm Chart files fail. Please fix the error and execute this script again."
     exit 1
