@@ -214,11 +214,11 @@ function ensure_kubectl_connection() {
   echo '[INFO] Checking kubectl connection.'
   for (( i=1; i<=3; i++ ))
   do
-    if [[  $(kubectl version > /dev/null 2>&1; echo $?) -eq 0 ]]; then
+    if [[  $(kubectl version --output=yaml > /dev/null 2>&1; echo $?) -eq 0 ]]; then
       break
     else
       if [[ $i -eq 3 ]]; then
-        kubectl version
+        kubectl version --output=yaml
         echo '[ERROR] Make sure the kube-config file is configured properly and the K8S cluser is reachable before rerunning the cms deployment scripts.'
         exit 1
       fi
@@ -484,7 +484,7 @@ function gen_java_cert() {
       kubectl get secret --request-timeout 30s -n $_namespace elastic-tls -o jsonpath='{.data.tls\.key}' | base64 -d - > $ca_folder/tls.key
 
       openssl pkcs12 -export -in $ca_folder/tls.crt -inkey $ca_folder/tls.key -out $ca_folder/tls.p12 -passout pass:$pass
-      keytool -importkeystore -v -srckeystore $ca_folder/tls.p12 -srcstoretype pkcs12 -destkeystore $ca_folder/tls.keystore -deststoretype jks -storepass $pass -srcstorepass $pass
+      keytool -importkeystore -v -srckeystore $ca_folder/tls.p12 -srcstoretype pkcs12 -destkeystore $ca_folder/tls.keystore -deststoretype jks -storepass $pass -srcstorepass $pass -noprompt 2>/dev/null
       keytool -import -trustcacerts -alias ca -file $ca_folder/ca.crt -keystore $ca_folder/ca.truststore -storetype jks -storepass $pass -noprompt
 
       JAVA_CA_TRUSTSTORE=$(cat $ca_folder/ca.truststore|base64 -w 0)
@@ -499,7 +499,7 @@ function prepare_helm() {
   
   ensure_kubectl_connection
 
-  K8S_MINOR_VERSION=$(kubectl version | grep "Server Version"|grep -o Minor:\"[0-9]*\"|grep -o [0-9]*)
+  K8S_MINOR_VERSION=$(kubectl version --output=yaml|yq '.serverVersion.minor')
  
   # Prepare helm
   if [[ $K8S_MINOR_VERSION -ge 18 ]];then
