@@ -124,25 +124,26 @@ function prepare_installer(){
     sudo ln -fs /usr/bin/yq_linux_amd64_v3.4.1 /usr/bin/yq
 
     #by far we change to yq v4.x, add binary and make yq link to yq4
-    if [[ -f $RPMFOLDER/yq/yq_linux_amd64_v4.25.2 ]]; then
+    if [[ -f $RPMFOLDER/yq/yq_linux_amd64_v4.32.2 ]]; then
       echo "[INFO] yq4 exists, upgrading ..."
-      sudo cp $RPMFOLDER/yq/yq_linux_amd64_v4.25.2 /usr/bin
-      sudo chmod +x /usr/bin/yq_linux_amd64_v4.25.2
-      sudo ln -fs /usr/bin/yq_linux_amd64_v4.25.2 /usr/bin/yq4
-      sudo ln -fs /usr/bin/yq_linux_amd64_v4.25.2 /usr/bin/yq
+      sudo cp $RPMFOLDER/yq/yq_linux_amd64_v4.32.2 /usr/bin
+      sudo chmod +x /usr/bin/yq_linux_amd64_v4.32.2
+      sudo ln -fs /usr/bin/yq_linux_amd64_v4.32.2 /usr/bin/yq4
+      sudo ln -fs /usr/bin/yq_linux_amd64_v4.32.2 /usr/bin/yq
       sudo ln -fs /usr/bin/yq_linux_amd64_v3.4.1 /usr/bin/yq3
     fi
   else
     YQ_VER=`yq -V|awk -F "version " '{print $2}'|cut -c1`
-    if [[ "$YQ_VER" == "3" ]]; then
-      if [[ -f $RPMFOLDER/yq/yq_linux_amd64_v4.25.2 ]]; then
-        echo "[INFO] yq4 exists, yq3->yq4 upgrading ..."
-        sudo cp $RPMFOLDER/yq/yq_linux_amd64_v4.25.2 /usr/bin
-        sudo chmod +x /usr/bin/yq_linux_amd64_v4.25.2
-        sudo ln -fs /usr/bin/yq_linux_amd64_v4.25.2 /usr/bin/yq4
-        sudo ln -fs /usr/bin/yq_linux_amd64_v4.25.2 /usr/bin/yq
+    #if [[ "$YQ_VER" == "3" ]]; then
+    if [[ $YQ_VER =~ ^3 || "$YQ_VER" == "4.25" ]]; then
+      if [[ -f $RPMFOLDER/yq/yq_linux_amd64_v4.32.2 ]]; then
+        echo "[INFO] Upgrading yq to v4.32.2..."
+        sudo cp $RPMFOLDER/yq/yq_linux_amd64_v4.32.2 /usr/bin
+        sudo chmod +x /usr/bin/yq_linux_amd64_v4.32.2
+        sudo ln -fs /usr/bin/yq_linux_amd64_v4.32.2 /usr/bin/yq4
+        sudo ln -fs /usr/bin/yq_linux_amd64_v4.32.2 /usr/bin/yq
         sudo ln -fs /usr/bin/yq_linux_amd64_v3.4.1 /usr/bin/yq3
-        sudo ln -fs /usr/bin/yq_linux_amd64_v4.25.2 /usr/local/bin/yq
+        sudo ln -fs /usr/bin/yq_linux_amd64_v4.32.2 /usr/local/bin/yq
       fi
     fi
   fi
